@@ -243,8 +243,8 @@ class ServiceNameCatalog:
         ServiceName("emr", "EMR"),
         ServiceName("es", "ElasticsearchService"),
         ServiceName("events", "EventBridge"),
-        ServiceName("finspace", "finspace"),
         ServiceName("finspace-data", "FinSpaceData"),
+        ServiceName("finspace", "finspace"),
         ServiceName("firehose", "Firehose"),
         ServiceName("fis", "FIS"),
         ServiceName("fms", "FMS"),
@@ -388,6 +388,8 @@ class ServiceNameCatalog:
         ServiceName("snowball", "Snowball"),
         ServiceName("sns", "SNS"),
         ServiceName("sqs", "SQS"),
+        ServiceName("ssm-contacts", "SSMContacts"),
+        ServiceName("ssm-incidents", "SSMIncidents"),
         ServiceName("ssm", "SSM"),
         ServiceName("sso-admin", "SSOAdmin"),
         ServiceName("sso-oidc", "SSOOIDC"),
